import os
import shutil
import re

def sort_files(input_folder):
    # 仕分け先フォルダーの定義
    output_folders = {
        "未修正": os.path.join(input_folder, "未修正"),
        "修正済み": os.path.join(input_folder, "修正済み"),
        "差分無し": os.path.join(input_folder, "差分無し"),
    }
    
    # 仕分け先フォルダーの作成
    for folder in output_folders.values():
        os.makedirs(folder, exist_ok=True)
    
    # ファイルのリスト取得
    files = [f for f in os.listdir(input_folder) if os.path.isfile(os.path.join(input_folder, f))]
    
    # ファイル名の解析用正規表現
    pattern = re.compile(r"^\d+-(\d+)(-before-censor)?\..+$")
    
    # ファイル分類用辞書
    file_groups = {}
    
    for file in files:
        match = pattern.match(file)
        if match:
            file_number = match.group(1)  # 1774316107 の部分
            is_before_censor = match.group(2) is not None
            
            if file_number not in file_groups:
                file_groups[file_number] = {"before_censor": None, "normal": None}
            
            if is_before_censor:
                file_groups[file_number]["before_censor"] = file
            else:
                file_groups[file_number]["normal"] = file
    
    # 仕分け処理
    for file_number, files in file_groups.items():
        before_censor_file = files["before_censor"]
        normal_file = files["normal"]
        
        if before_censor_file:
            shutil.move(os.path.join(input_folder, before_censor_file), output_folders["未修正"])
        
        if normal_file:
            if before_censor_file:
                shutil.move(os.path.join(input_folder, normal_file), output_folders["修正済み"])
            else:
                shutil.move(os.path.join(input_folder, normal_file), output_folders["差分無し"])

if __name__ == "__main__":
    input_folder = "Input"
    sort_files(input_folder)
    print("ファイルの仕分けが完了しました！")
